=======
Qtickle
=======

A script designed to aid in saving values inside Qt objects.
It works by inspecting for objectnames and then collecting their
values.

The name is a portmanteau of Qt and pickle. Originally the script
utilized pickle to save data. Now data is returned in the form of
a dictionary. This way the user gets to choose what happens to the
data

Install
-------

    pip install Qtickle

